@@ -1,7 +1,7 @@
 /*
 	Scape.h
 	
-	Copyright 2004-5 Tim Goetze <tim@quitte.de>
+	Copyright 2004-16 Tim Goetze <tim@quitte.de>
 	
 	http://quitte.de/dsp/
 
@@ -45,6 +45,7 @@ class Scape
 		struct {
 			DSP::Lorenz lorenz;
 			DSP::LP1<sample_t> lp;
+			sample_t get() { return lp.process(lorenz.get()); }
 		} lfo[2];
 
 		DSP::Delay delay;
@@ -60,4 +61,21 @@ class Scape
 		void activate();
 };
 
+class DDDelay
+: public Plugin
+{
+	public:
+		struct {
+			DSP::Delay delay;
+			DSP::LP1<sample_t> lp;
+		} step[4];
+		void cycle (uint frames);
+
+	public:
+		static PortInfo port_info [];
+
+		void init();
+		void activate();
+};
+
 #endif /* SCAPE_H */
